@@ -1,7 +1,10 @@
 from django.core.exceptions import ValidationError
-from django.contrib.auth.hashers import check_password, make_password
+from django.contrib.auth.hashers import check_password
 from django.utils.translation import gettext as _
+from django.utils import timezone
+
 import re
+from datetime import timedelta
 
 
 class ComplexityValidator:
@@ -82,15 +85,34 @@ class RepeatedValidator:
                     code='password_repeated',
                 )
 
-    def password_changed(self, password, user=None):
-        # In case there is no user, this is not applicable.
-        if user is None:
-            return None
-
-        hashed_password = make_password(password)
-        user.password_records.create(password=hashed_password)
-
     def get_help_text(self):
         return _(
             f"密碼不可與最近{self.record_length}次使用過的密碼重複。"
         )
+
+
+class MinimumResetIntervalValidator:
+
+    def __init__(self, min_interval_days=1):
+        self.min_interval = timedelta(days=min_interval_days)
+
+    def validate(self, password, user=None):
+        # In case there is no user, this validator is not applicable.
+        if user is None:
+            return None
+        latest_password_record = (
+            user.objects.order_by('-date').first()
+        )
+        if not latest_password_record:
+            return None
+        if (timezone.now() - latest_password_record.date) \
+                < self.min_interval:
+            raise ValidationError(
+                _(f"距上次變更密碼須至少間隔{self.min_interval.days}日。"),
+                code='password_reset_interval',
+            )
+
+    def get_help_text(self):
+        return _(
+            f"距上次變更密碼須至少間隔{self.min_interval.days}日。"
+        )
